@@ -1,8 +1,7 @@
 #!/usr/bin/env perl
 
 package Analog::Mapper;
-our $VERSION = '0.100270';
-use Moose;
+use Moo;
 with 'Hadoop::Streaming::Mapper';
 
 sub map {
@@ -13,5 +12,4 @@ sub map {
 }
 
 package main;
-our $VERSION = '0.100270';
 Analog::Mapper->run;
