@@ -1,8 +1,6 @@
 package Hadoop::Streaming::Mapper;
-{
-  $Hadoop::Streaming::Mapper::VERSION = '0.122420';
-}
-use Any::Moose qw(Role);
+$Hadoop::Streaming::Mapper::VERSION = '0.143060';
+use Moo::Role;
 use IO::Handle;
 
 with 'Hadoop::Streaming::Role::Emitter';
@@ -29,22 +27,25 @@ sub run
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hadoop::Streaming::Mapper - Simplify writing Hadoop Streaming Mapper jobs.  Write a map() function and let this role handle the Stream interface.
 
 =head1 VERSION
 
-version 0.122420
+version 0.143060
 
 =head1 SYNOPSIS
 
   #!/usr/bin/env perl
   
   package Wordcount::Mapper;
-  use Any::Moose;
+  use Moo;
   with 'Hadoop::Streaming::Mapper';
   
   sub map
@@ -111,10 +112,9 @@ Naoya Ito <naoya@hatena.ne.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Naoya Ito <naoya@hatena.ne.jp>.
+This software is copyright (c) 2014 by Naoya Ito <naoya@hatena.ne.jp>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
