@@ -1,8 +1,6 @@
 package Hadoop::Streaming::Reducer;
-{
-  $Hadoop::Streaming::Reducer::VERSION = '0.122420';
-}
-use Any::Moose qw(Role);
+$Hadoop::Streaming::Reducer::VERSION = '0.143060';
+use Moo::Role;
 
 use IO::Handle;
 use Hadoop::Streaming::Reducer::Input;
@@ -34,24 +32,26 @@ sub run {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hadoop::Streaming::Reducer - Simplify writing Hadoop Streaming jobs. Write a reduce() function and let this role handle the Stream interface.  This Reducer roll provides an iterator over the multiple values for a given key.
 
 =head1 VERSION
 
-version 0.122420
+version 0.143060
 
 =head1 SYNOPSIS
 
     #!/usr/bin/env perl
 
     package WordCount::Reducer;
-    use Any::Moose;
+    use Moo;
     with qw/Hadoop::Streaming::Reducer/;
 
     sub reduce {
@@ -101,10 +101,9 @@ Naoya Ito <naoya@hatena.ne.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Naoya Ito <naoya@hatena.ne.jp>.
+This software is copyright (c) 2014 by Naoya Ito <naoya@hatena.ne.jp>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
