@@ -1,8 +1,6 @@
 package Hadoop::Streaming::Reducer::Input;
-{
-  $Hadoop::Streaming::Reducer::Input::VERSION = '0.122420';
-}
-use Any::Moose;
+$Hadoop::Streaming::Reducer::Input::VERSION = '0.143060';
+use Moo;
 use Hadoop::Streaming::Reducer::Input::Iterator;
 
 #ABSTRACT: Parse input stream for reducer
@@ -67,15 +65,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hadoop::Streaming::Reducer::Input - Parse input stream for reducer
 
 =head1 VERSION
 
-version 0.122420
+version 0.143060
 
 =head1 METHODS
 
@@ -129,10 +130,9 @@ Naoya Ito <naoya@hatena.ne.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Naoya Ito <naoya@hatena.ne.jp>.
+This software is copyright (c) 2014 by Naoya Ito <naoya@hatena.ne.jp>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
