@@ -1,8 +1,6 @@
 package Hadoop::Streaming::Reducer::Input::ValuesIterator;
-{
-  $Hadoop::Streaming::Reducer::Input::ValuesIterator::VERSION = '0.122420';
-}
-use Any::Moose;
+$Hadoop::Streaming::Reducer::Input::ValuesIterator::VERSION = '0.143060';
+use Moo;
 with 'Hadoop::Streaming::Role::Iterator';
 
 #ABSTRACT: Role providing access to values for a given key.
@@ -43,15 +41,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hadoop::Streaming::Reducer::Input::ValuesIterator - Role providing access to values for a given key.
 
 =head1 VERSION
 
-version 0.122420
+version 0.143060
 
 =head1 METHODS
 
@@ -85,10 +86,9 @@ Naoya Ito <naoya@hatena.ne.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Naoya Ito <naoya@hatena.ne.jp>.
+This software is copyright (c) 2014 by Naoya Ito <naoya@hatena.ne.jp>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
