@@ -1,8 +1,6 @@
 package Hadoop::Streaming::Role::Emitter;
-{
-  $Hadoop::Streaming::Role::Emitter::VERSION = '0.122420';
-}
-use Any::Moose qw(Role);
+$Hadoop::Streaming::Role::Emitter::VERSION = '0.143060';
+use Moo::Role;
 use Params::Validate qw/validate_pos/;
 
 #provides qw(run emit counter status);
@@ -53,15 +51,18 @@ sub status
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Hadoop::Streaming::Role::Emitter - Role to provide emit, counter, and status interaction with Hadoop::Streaming.
 
 =head1 VERSION
 
-version 0.122420
+version 0.143060
 
 =head1 METHODS
 
@@ -114,10 +115,9 @@ Naoya Ito <naoya@hatena.ne.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Naoya Ito <naoya@hatena.ne.jp>.
+This software is copyright (c) 2014 by Naoya Ito <naoya@hatena.ne.jp>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
