@@ -1,8 +1,7 @@
 #!/usr/bin/env perl
 
 package Analog::Reducer;
-our $VERSION = '0.100270';
-use Moose;
+use Moo;
 with 'Hadoop::Streaming::Reducer';
 
 sub reduce {
@@ -17,5 +16,4 @@ sub reduce {
 }
 
 package main;
-our $VERSION = '0.100270';
 Analog::Reducer->run;
